SBlog
======

##Intro
This is a simple static blog generator.  
markdown,ga,disqus are supported.

##Usage
1. install  
shell:python setup.py install
2. build an environment  
shell:cd /new/dir/
shell:sblog
3. config  
vi config.ini
4. write  

demo:  
<pre>
    ======
    title: hello world  
    date: 0000-00-00   
    folder: test  
    ======
    content with markdown supporting  
    ~~~python  
    source code here  
    ~~~  
</pre>

View [demo](http://blog.xiaoba.me)


##
CHANGE LOG

v1.0.5: private post & post preview support.

v1.0.4: custom theme support.
